Design information for nocasedict project
==============================================================

This directory contains loosely organized files in markdown, text or RST format
containing design information on the project.

Design information is not included in the public project documentation.
